void hit(void)
{
  say_xy("wscream.wav/22050Hz - Chealse in Stonebrook", 0, 380);
  playsound(12, 22050, 0, 0, 0);
}

void talk(void)
{
  say_xy("wscream.wav/5512Hz - Lyna's Story - DDC ressurect", 0, 380);
  // Henry.c, sound #50
  playsound(12, 5512, 0, 0, 0);
}
